# pylibchecker [![PyPI version](https://badge.fury.io/py/pylibchecker.svg)](https://badge.fury.io/py/pylibchecker)

Utils inspired by [LibChecker](https://github.com/LibChecker/LibChecker), checking Android so files.

## Reference

- [LibChecker](https://github.com/LibChecker/LibChecker) used, license under Apache License 2.0.
